"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const apputils_1 = require("@jupyterlab/apputils");
const coreutils_1 = require("@jupyterlab/coreutils");
const widgets_1 = require("@phosphor/widgets");
require("./browser-connector");
/**
 * Show a dialog for entering MapD connection data.
 */
function showConnectionDialog(oldConnection) {
    return apputils_1.showDialog({
        title: 'MapD Connection',
        body: new MapDConnectionDialog(oldConnection),
        buttons: [apputils_1.Dialog.cancelButton(), apputils_1.Dialog.okButton()]
    }).then(result => {
        if (result.button.accept) {
            return result.value;
        }
        else {
            return oldConnection;
        }
    });
}
exports.showConnectionDialog = showConnectionDialog;
/**
 * A dialog for entering MapD connection data.
 */
class MapDConnectionDialog extends widgets_1.Widget {
    constructor(oldData) {
        super();
        let layout = (this.layout = new widgets_1.PanelLayout());
        this._user = document.createElement('input');
        this._password = document.createElement('input');
        this._database = document.createElement('input');
        this._host = document.createElement('input');
        this._protocol = document.createElement('input');
        this._port = document.createElement('input');
        this._user.placeholder = 'User name';
        this._password.placeholder = 'Password';
        this._password.setAttribute('type', 'password');
        this._database.placeholder = 'Database name';
        this._host.placeholder = 'Host name';
        this._protocol.placeholder = 'Protocol';
        this._port.placeholder = 'Port';
        if (oldData) {
            this._user.value = oldData.user;
            this._password.value = oldData.password;
            this._database.value = oldData.dbName;
            this._host.value = oldData.host;
            this._protocol.value = oldData.protocol;
            this._port.value = oldData.port;
        }
        const userLabel = new widgets_1.Widget();
        userLabel.node.textContent = 'User';
        const passwordLabel = new widgets_1.Widget();
        passwordLabel.node.textContent = 'Password';
        const databaseLabel = new widgets_1.Widget();
        databaseLabel.node.textContent = 'Database';
        const hostLabel = new widgets_1.Widget();
        hostLabel.node.textContent = 'Host';
        const protocolLabel = new widgets_1.Widget();
        protocolLabel.node.textContent = 'Protocol';
        const portLabel = new widgets_1.Widget();
        portLabel.node.textContent = 'Port';
        layout.addWidget(userLabel);
        layout.addWidget(new widgets_1.Widget({ node: this._user }));
        layout.addWidget(passwordLabel);
        layout.addWidget(new widgets_1.Widget({ node: this._password }));
        layout.addWidget(databaseLabel);
        layout.addWidget(new widgets_1.Widget({ node: this._database }));
        layout.addWidget(hostLabel);
        layout.addWidget(new widgets_1.Widget({ node: this._host }));
        layout.addWidget(protocolLabel);
        layout.addWidget(new widgets_1.Widget({ node: this._protocol }));
        layout.addWidget(portLabel);
        layout.addWidget(new widgets_1.Widget({ node: this._port }));
    }
    getValue() {
        return {
            user: this._user.value,
            password: this._password.value,
            dbName: this._database.value,
            host: this._host.value,
            protocol: this._protocol.value,
            port: this._port.value
        };
    }
}
exports.MapDConnectionDialog = MapDConnectionDialog;
/**
 * A class for fetching completion data from a MapD connection.
 */
class MapDCompletionConnector extends coreutils_1.DataConnector {
    /**
     * Construct a new completion connector.
     */
    constructor(connection) {
        super();
        this._connection = connection;
    }
    /**
     * Fetch completion data from the MapD backend.
     */
    fetch(request) {
        const connection = this._connection;
        return new Promise((resolve, reject) => {
            new MapdCon()
                .protocol(connection.protocol)
                .host(connection.host)
                .port(connection.port)
                .dbName(connection.dbName)
                .user(connection.user)
                .password(connection.password)
                .connect((error, con) => {
                if (error) {
                    reject(error);
                }
                else {
                    con.getCompletionHints(request.text, { cursor: request.offset }, (err, result) => {
                        if (err) {
                            reject(err);
                        }
                        else if (result && result[0] && result[0].hints) {
                            const matches = result
                                .map((hintObject) => hintObject.hints)
                                .reduce((acc, val) => [].concat(acc, val), []);
                            resolve({
                                start: request.offset - result[0].replaced.length,
                                end: request.offset,
                                matches,
                                metadata: {}
                            });
                            resolve(void 0);
                        }
                        else {
                            resolve(void 0);
                        }
                    });
                }
            });
        });
    }
}
exports.MapDCompletionConnector = MapDCompletionConnector;
