"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const coreutils_1 = require("@phosphor/coreutils");
const widgets_1 = require("@phosphor/widgets");
const apputils_1 = require("@jupyterlab/apputils");
const docregistry_1 = require("@jupyterlab/docregistry");
const connection_1 = require("./connection");
const widget_1 = require("./widget");
class MapDViewer extends docregistry_1.DocumentWidget {
    constructor(context, connection) {
        super({
            context,
            reveal: context.ready.then(() => this._render()),
            content: new widgets_1.Widget()
        });
        this._ready = new coreutils_1.PromiseDelegate();
        this._widget = null;
        this.toolbar.addClass('mapd-MapD-toolbar');
        this.addClass('mapd-MapDViewer-content');
        this.toolbar.addItem('Render', new apputils_1.ToolbarButton({
            iconClassName: 'jp-RunIcon jp-Icon jp-Icon-16',
            onClick: () => {
                this._render();
            },
            tooltip: 'Render'
        }));
        this.toolbar.addItem('Connect', new apputils_1.ToolbarButton({
            iconClassName: 'mapd-MapD-logo jp-Icon jp-Icon-16',
            onClick: () => {
                connection_1.showConnectionDialog(this._connection).then(connection => {
                    this._connection = connection;
                });
            },
            tooltip: 'Enter MapD Connection Data'
        }));
    }
    /**
     * The current connection data for the viewer.
     */
    get connection() {
        return this._connection;
    }
    set connection(value) {
        this._connection = value;
    }
    /**
     * A promise that resolves when the viewer is ready.
     */
    get ready() {
        return this._ready.promise;
    }
    /**
     * Render MapD into this widget's node.
     */
    _render() {
        if (this._widget) {
            this.content.node.removeChild(this._widget.node);
            this._widget.dispose();
            this._widget = null;
        }
        const text = this.context.model.toString();
        // If there is no data or no connection, do nothing
        if (!text || !this._connection) {
            return Promise.resolve(void 0);
        }
        const data = JSON.parse(text.replace(/\n/g, ''));
        this._widget = new widget_1.MapDVega(data, this._connection);
        this.content.node.appendChild(this._widget.node);
        const spinner = new apputils_1.Spinner();
        this.content.node.appendChild(spinner.node);
        return this._widget.renderedImage
            .then(() => {
            this.content.node.removeChild(spinner.node);
            spinner.dispose();
            return void 0;
        })
            .catch(() => {
            this.content.node.removeChild(spinner.node);
            spinner.dispose();
            return void 0;
        });
    }
}
exports.MapDViewer = MapDViewer;
/**
 * A widget factory for images.
 */
class MapDViewerFactory extends docregistry_1.ABCWidgetFactory {
    /**
     * Create a new widget given a context.
     */
    createNewWidget(context) {
        return new MapDViewer(context, this.defaultConnection);
    }
    /**
     * The current default connection data for viewers.
     */
    get defaultConnection() {
        return this._defaultConnection;
    }
    set defaultConnection(value) {
        this._defaultConnection = value;
    }
}
exports.MapDViewerFactory = MapDViewerFactory;
