"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const coreutils_1 = require("@phosphor/coreutils");
const widgets_1 = require("@phosphor/widgets");
/**
 * The MIME type for png data.
 */
const IMAGE_MIME = 'image/png';
/**
 * A class for rendering a MapD-generated image.
 */
class MapDVega extends widgets_1.Widget {
    /**
     * Construct a new MapD widget.
     */
    constructor(vega, connection, vegaLite) {
        super();
        this._rendered = new coreutils_1.PromiseDelegate();
        this.addClass('mapd-MapDVega');
        this._img = document.createElement('img');
        this._error = document.createElement('pre');
        this._error.className = 'mapd-ErrorMessage';
        this.node.appendChild(this._img);
        this.node.appendChild(this._error);
        this._connection = connection;
        this._vega = vega;
        // _vegaLite is just for debugging, in case we get an error, we can show it.
        this._vegaLite = vegaLite;
        this._renderData();
    }
    get renderedImage() {
        return this._rendered.promise;
    }
    _renderData() {
        const connection = this._connection;
        const vega = this._vega;
        new MapdCon()
            .protocol(connection.protocol)
            .host(connection.host)
            .port(connection.port)
            .dbName(connection.dbName)
            .user(connection.user)
            .password(connection.password)
            .connect((error, con) => {
            if (error) {
                // If there was an error, clear any image data,
                // and set the text content of the error node.
                this._setImageData('');
                this._error.textContent = error;
                this._rendered.reject(error);
                return;
            }
            con.renderVega(Private.id++, JSON.stringify(vega), {}, (error, result) => {
                if (error) {
                    // If there was an error, clear any image data,
                    // and set the text content of the error node.
                    this._setImageData('');
                    this._error.textContent = error.message;
                    if (this._vegaLite) {
                        this._error.textContent += `\n\nVega Lite:\n${JSON.stringify(this._vegaLite, null, 2)}`;
                    }
                    this._error.textContent += `\n\nVega:\n${JSON.stringify(vega, null, 2)}`;
                    this._rendered.reject(error.message);
                }
                else {
                    // Set the image data.
                    this._setImageData(result.image);
                    // Clear any error message.
                    this._error.textContent = '';
                    this._rendered.resolve(result.image);
                }
            });
        });
    }
    /**
     * Set the image data to a base64 encoded string.
     */
    _setImageData(blob) {
        let blobUrl = `data:${IMAGE_MIME};base64,${blob}`;
        this._img.src = blobUrl;
    }
}
exports.MapDVega = MapDVega;
/**
 * A namespace for private data.
 */
var Private;
(function (Private) {
    Private.id = 0;
})(Private || (Private = {}));
